// -*- C++ -*-
//===------------------- support/fuchsia/xlocale.h ------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_SUPPORT_FUCHSIA_XLOCALE_H
#define _LIBCPP_SUPPORT_FUCHSIA_XLOCALE_H

#if defined(__Fuchsia__)

#include <cstdlib>
#include <cwchar>
#include <support/xlocale/__posix_l_fallback.h>
#include <support/xlocale/__strtonum_fallback.h>

#endif // defined(__Fuchsia__)

#endif // _LIBCPP_SUPPORT_FUCHSIA_XLOCALE_H
